==> haskell-hslua-module-version-1.1.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-7NBOqyQ5NHoyGLMl9Xp9
key:                  hslua-module-version-1.1.1-7NBOqyQ5NHoyGLMl9Xp9
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  3fffbb2c4fa68e5ba3adba49c4df58d3
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-7NBOqyQ5NHoyGLMl9Xp9
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-777UADJFM7tGoBZHSEM2Wb
    hslua-marshalling-2.3.1-EVwxTaJ2lUw1GbUN2Ktkk8
    hslua-packaging-2.3.1-4CqDLKknSAOHQCd019j6jg text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-7Y6EluP2CP5BptkMal1S7U
key:                  hslua-module-version-1.1.1-7Y6EluP2CP5BptkMal1S7U
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  1de49d408a90ebd6508eaa2a01e32167
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-7Y6EluP2CP5BptkMal1S7U
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-606LMJIe4Bk53wfFH7ZnNz
    hslua-marshalling-2.3.1-AGUOK3lAMNUEZ6L4KFHOnx
    hslua-packaging-2.3.1-7cxSlQcBRI2KcGyWFPWdz1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
